# ontologia/codicem/sexum

## binarium.hxl.csv
- [binarium.hxl.csv](binarium.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:sexum:binarium`
- https://github.com/HXL-CPLP/forum/issues/50
- https://en.wikipedia.org/wiki/ISO/IEC_5218


## hl7.hxl.csv
- [hl7.hxl.csv](hl7.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:sexum:hl7`
- https://github.com/HXL-CPLP/forum/issues/50
- https://en.wikipedia.org/wiki/ISO/IEC_5218
- https://confluence.hl7.org/display/VOC/Gender+Coding+with+International+Data+Exchange+Standards


## non-binarium.hxl.csv
- [non-binarium.hxl.csv](non-binarium.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:sexum:non-binarium`
- https://github.com/HXL-CPLP/forum/issues/50
- https://en.wikipedia.org/wiki/ISO/IEC_5218
- https://confluence.hl7.org/display/VOC/Gender+Coding+with+International+Data+Exchange+Standards
